Robust Statistics
=================
.. versionchanged:: 0.4.0
   Function names have been changed in this module and new function added.  See the below
   for more details.

.. automodule:: lsl.statistics.robust
   :members:

Statistical Tests
=================
.. versionadded:: 0.4.0
.. automodule:: lsl.statistics.stattests
   :members:

